@@ -1,4 +1,4 @@
- .calc_extBIC_MLE <- function(trait=NULL, currentX=NULL, MMt=NULL,  geno=NULL, Zmat=NULL, numberSNPselected=0, quiet=TRUE, gamma=NULL, eig.L=NULL)
+ .calc_extBIC_MLE <- function(trait=NULL, currentX=NULL, MMt=NULL,  geno=NULL, Zmat=NULL, numberSNPselected=0, quiet=TRUE, lambda=NULL, eig.L=NULL)
  {
    ## internal function: used by AM 
    ## smallest extBIC and BIC is best
@@ -10,23 +10,23 @@
    BIC <- -2 * res_p$ML + (ncol(currentX)+1) * log(length(trait))  ## fixed effects + variance component
 
 
-  # calculate gamma
-  if(is.null(gamma)){
-     gamma <- 1
+  # calculate lambda
+  if(is.null(lambda)){
+     lambda <- 1
      # found this to be anti-conservative when sample size is small
      #lambda <- log(geno$dim_of_M[2])/log(length(trait))
-     #gamma <- 1-(1/(2*lambda))
+     #lambda <- 1-(1/(2*lambda))
    } ## outer if
 
-  if(length(gamma)==1){
-   extBIC <- BIC + 2 * gamma   *lchoose(geno$dim_of_M[2], numberSNPselected)  
+  if(length(lambda)==1){
+   extBIC <- BIC + 2 * lambda   *lchoose(geno$dim_of_M[2], numberSNPselected)  
    if(!quiet){
-      cat(" Gamma = ", gamma, "\n")
+      cat(" Gamma = ", lambda, "\n")
    }
    } else {
-     extBIC <- rep(NA, length(gamma))
-     for(ii in 1:length(gamma)){
-        extBIC[ii] <- BIC + 2 * gamma[ii]  *lchoose(geno$dim_of_M[2], numberSNPselected)
+     extBIC <- rep(NA, length(lambda))
+     for(ii in 1:length(lambda)){
+        extBIC[ii] <- BIC + 2 * lambda[ii]  *lchoose(geno$dim_of_M[2], numberSNPselected)
      }
 
    }
