@@ -132,14 +132,14 @@ message( sprintf("%-40s  %-10s", "Trait name: ", lst[["traitname"]] ))
 message( sprintf("%-40s  %-30s", "Fixed model: ", lst[["fformula"]] ))
 message( sprintf("%-40s  %-10s", "Number samples missing obs:", lst[["nummissingpheno"]] ))
 message( sprintf("%-40s  %-10s", "Number significant snp-trait assocs:", lst[["numSigSNP"]] ))
-message( sprintf("%-40s  %-4s", "Gamma value for extBIC: ", round(lst[["lambda"]],2)  ))
+message( sprintf("%-40s  %-4s", "Lambda value for extBIC: ", round(lst[["lambda"]],2)  ))
 message(  sprintf("%50s", "--------------------------------------------------------" ))
 message("\n\n")
 
 # create data frame of summary information for use in shiny app
 infodf <- data.frame("description"= c("Number cpu", "Max memory (Gb)", "Number of samples", "Number of snp", 
                                     "Trait name", "Fixed model", "Number samples missing obs", 
-                                    "Number significant snp-trait assocs", "Gamma value for extBIC"  )   ,
+                                    "Number significant snp-trait assocs", "Lambda value for extBIC"  )   ,
                    "value" = c(lst[["ncpu"]], lst[["memory"]], lst[["numsamples"]], 
                      lst[["numsnp"]], lst[["traitname"]], lst[["fformula"]], lst[["nummissingpheno"]], 
                     lst[["numSigSNP"]], round(lst[["lambda"]],2)   )
